@@ -239,7 +239,7 @@ set_selected_category (GtkWidget G_GNUC_UNUSED *ui, GSList *selected, gpointer u
 static void
 on_categories_clicked (GtkButton G_GNUC_UNUSED *button, gpointer user_data)
 {
-	GtkWidget *w;
+	GtkWidget * G_GNUC_UNUSED w;
 
 	w = gpe_pim_categories_dialog (gpe_pim_categories_list (), 
 			G_CALLBACK (set_selected_category), user_data);
@@ -1006,8 +1006,6 @@ set_toolbar (GpeExpenseData *context)
 void
 open_expenses_window (GpeExpenseData *context)
 {
-	gboolean large_screen;
-	gboolean mode_landscape;
 	GtkWidget *window;
 	GtkWidget *vbox;
 
@@ -1015,8 +1013,6 @@ open_expenses_window (GpeExpenseData *context)
 	ENTER (" ");
 	vbox = gtk_vbox_new (FALSE, 0);
 
-	large_screen = (gdk_screen_width() > 400);
-	mode_landscape = (gdk_screen_width() > gdk_screen_height());
 	gpe_pim_categories_init ();
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_default_size (GTK_WINDOW (window), 240, 320);
