@@ -1,8 +1,8 @@
 /***************************************************************************
  *            qof-expenses.h
  *
- *  Thu Oct 21 08:18:44 2004-2005
- *  Copyright  2004,2005,2006  Neil Williams  <linux@codehelp.co.uk>
+ *  Thu Oct 21 08:18:44 2004
+ *  Copyright  2004,2005,2006,2009  Neil Williams  <linux@codehelp.co.uk>
  ****************************************************************************/
 /*
     This package is free software; you can redistribute it and/or modify
@@ -26,6 +26,11 @@
 	Like ::DB, Expenses uses UTC time within QOF and sets localtime when
 	calling pilot-link code.
 
+Gradually becoming a standard QOF method, whilst retaining compatibility
+with the simple pilot-link currency handling instead of going the whole
+hog to GnuCash currencies. The old Expense_t has been removed for easier
+sharing between applications.
+ 
 The typed enumerators ::ExpenseDistance, ::ExpenseType and ::ExpensePayment 
 may look strange initially because macros are used to ensure
 that the enum value and a string version of the enum are always in sync.
@@ -61,8 +66,8 @@ are only accessible via the library. See ::ExpenseType and
 
 	@{ */
 /** @file  qof-expenses.h
-	@brief QOF expense definitions for pilot-link
-	@author Copyright (c) 2004-2005 Neil Williams <linux@codehelp.co.uk>
+	@brief QOF expense definitions
+	@author Copyright (c) 2004-2009 Neil Williams <linux@codehelp.co.uk>
 */
 
 #ifndef _QOF_EXPENSES_H
@@ -71,6 +76,7 @@ are only accessible via the library. See ::ExpenseType and
 #include <glib.h>
 #include <qof.h>
 
+/** @bug need to support qof-expenses and gpe-expenses */
 #define GPE_MOD_EXP "gpe-expenses-module"
 #define GPE_QOF_EXPENSES "gpe_expenses"
 #define QOF_EXPENSES_DESC "GPE QOF expenses"
@@ -87,28 +93,22 @@ are only accessible via the library. See ::ExpenseType and
 #define EXP_DISTANCE  "distance_unit"
 #define EXP_KVP       "currency_lookup"
 
-/** type:  KVP_TYPE_STRING */
+/** type:  KVP_TYPE_STRING - inherited from pilot-link via pilot-qof. */
 #define PQ_CURRENCY_MNEMONIC "expense/currency/mnemonic"  
-/** type:  KVP_TYPE_STRING */
+/** type:  KVP_TYPE_STRING - inherited from pilot-link via pilot-qof. */
 #define PQ_CURRENCY_SYMBOL   "expense/currency/symbol"
-/** type:  KVP_TYPE_GINT64 */
+/** type:  KVP_TYPE_GINT64 - inherited from pilot-link via pilot-qof. */
 #define PQ_CURRENCY_FRACTION "expense/currency/fraction"
 
-typedef struct Expense Expense_t;
 
-/** \brief Wraps QOF around Expense_t
-
-This allows QOF to build as an option rather than adding QofInstance to
-Expense_t and requiring QOF for all builds.
-
-*/
+/** \brief Wraps QOF around pilot-link expenses */
 typedef struct QofExp_s QofExp;
 
-typedef void (*GpeCurrencyCB) (gpointer key, gpointer value, gpointer user_data);
+typedef void (*QofCurrencyCB) (gpointer key, gpointer value, gpointer user_data);
 
-void gpe_currency_foreach(GpeCurrencyCB cb, gpointer user_data);
+void qof_currency_foreach(QofCurrencyCB cb, gpointer user_data);
 
-/** \brief gpe-expenses currency data wrapper.
+/** \brief qof-expenses currency data wrapper.
 
 Uses the same format as the Palm Default Currency Table:
 
@@ -128,11 +128,11 @@ typedef struct
 	this is only useful if the symbol can still be shown
 	as iso-8859-1.) */	
 	gboolean        non_utf8;
-}GpeCurrency;
+}QofCurrency;
 
-/** \brief Set details of a GpeCurrency from a currency_code
+/** \brief Set details of a QofCurrency from a currency_code
 
-Lookup details of a GpeCurrency from a short identifier. The
+Lookup details of a QofCurrency from a short identifier. The
 QofInstance will have a KvpFrame set (replacing any existing
 values for the same keys) containing:
  -::PQ_CURRENCY_MNEMONIC
@@ -143,12 +143,12 @@ values for the same keys) containing:
 	details of the currency.
 \param currency_code The identifier of this currency.
 
-\return a pointer to the GpeCurrency identified by the
+\return a pointer to the QofCurrency identified by the
 	currency_code or NULL on error.
 
 */
-GpeCurrency *
-gpe_currency_lookup (QofInstance* inst, gint currency_code);
+QofCurrency *
+qof_currency_lookup (QofInstance* inst, gint currency_code);
 
 /** \brief Lookup a currency by name
 
@@ -156,8 +156,8 @@ Slower than ::gpe_currency_lookup because the entire currency
 hash must be searched. Otherwise, equivalent.
 
 */
-GpeCurrency *
-gpe_currency_lookup_name (QofInstance* inst, gchar * mnemonic);
+QofCurrency *
+qof_currency_lookup_name (QofInstance* inst, gchar * mnemonic);
 
 #define DISTANCE_LIST(_) \
  _(Miles, = 0) \
