@@ -23,8 +23,12 @@
 # in any source file. For this reason, it is safe to use
 # gcc here, even if the package is being cross-compiled.
 
+cd src
+if [ -f translate.h ]; then
+	rm translate.h
+fi
 # see the doxygen docs for more information.
-gcc -I.. -E translate.c 1> translate.h 2>/dev/null
+gcc -I.. -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/qof/ -E translate.c 1> translate.h 2>/dev/null
 
 # gcc -E returns non-zero so wrap it.
 exit 0
